@@ -5,7 +5,7 @@
 //!
 //! * the streaming [`XmlWriter`] requires its arguments to implement these traits
 //!
-//! * structure your code with the `tag!` macro (plays well with `rustfmt`)
+//! * an intuitive but **powerful eDSL** to structure your code (plays well with `rustfmt`)
 //!
 //! If you forget to escape a string, your code just doesn't compile.
 //! To prevent XML injections keep two things in mind:
@@ -19,12 +19,12 @@
 //! ## Example
 //!
 //! ```
-//! use std::fmt::{Error, Write};
+//! use std::fmt::Error;
 //! use xmlsafe::{XmlWriter, format_text, escape_text, with_writer};
 //!
 //! struct User {name: String, id: u8}
 //!
-//! fn list_users(mut w: XmlWriter, users: Vec<User>) -> Result<(), Error> {
+//! fn list_users(w: XmlWriter, users: Vec<User>) -> Result<(), Error> {
 //!     with_writer!(w, {
 //!         tag!("div", "class"="users", {
 //!             w.write(format_text!("There are {} users:", users.len()))?;
@@ -54,15 +54,18 @@
 //! note that if we forgot the `escape_text` call, the example would not
 //! compile.
 //!
+//! For the more advanced features of the eDSL, refer to the [`with_writer!`]
+//! documentation.
+//!
 //! ## Safety
 //!
 //! xmlsafe forbids `unsafe` code and does not panic.
 
 mod escape;
 mod macros;
-mod marker_traits;
+mod traits;
 mod writer;
 
 pub use crate::escape::{escape_att_value, escape_text, EscapedAttValue, EscapedPcdata};
-pub use marker_traits::{AttValueSafe, NameSafe, PcdataSafe};
+pub use traits::{AttValueSafe, NameSafe, PcdataSafe, TagConstructor};
 pub use writer::{AttValueWriter, AttWriter, XmlWriter};
